@@ -45,7 +45,6 @@ using namespace QtMobility;
 //#include <libosso-abook/osso-abook-util.h>
 
 QrSink::QrSink(const PluginInterface *interface) : PluginAction(interface) {
-    ready = false;
     image = QImage(":/images/qrcode.png");
     image = image.scaledToHeight(48, Qt::SmoothTransformation);
 }
@@ -287,16 +286,10 @@ void QrSink::barcodeAnalysed(QString barcodeType, QString barcodeData) {
         }
 
 
-        ready = true;
-    } else {
-        ready = false;
+        emit isReady();
     }
 }
 
-bool QrSink::isReady() {
-    return ready;
-}
-
 
 
 
@@ -304,6 +297,7 @@ bool QrSink::isReady() {
 // uses GLib, need to convert to pure Qt
 void QrSink::openInstallFile(QString data)
 {
+    Q_UNUSED(data)
 //    FILE *install_file;
 //    gchar *data = g_strdup(data1);
 //    char *filename=NULL;
@@ -963,7 +957,7 @@ void QrSink::addMECARD(QString user_data)
 
 void QrSink::addiCal(QString user_data)
 {
-
+    Q_UNUSED(user_data)
     /*
     // wait for qt-mobility 1.1 + versit
     #include <QVersitOrganizerImporter>
