@@ -6,7 +6,7 @@
 #include <mbarcode-qt/plugininterfaces.h>
 #include <mbarcode-qt/pluginaction.h>
 
-class QrSink : public QObject, public PluginAction
+class QrSink : public PluginAction
 {
     Q_OBJECT
 public:
@@ -33,10 +33,11 @@ public:
     QString getText();
     QImage getImage();
     QString getInformativeText();
-    bool isReady();
     void clickAction(QWidget *parentWindow);
     // other
     //QString url;
+signals:
+    void isReady();
 private slots:
     void barcodeAnalysed(QString barcodeType, QString barcodeData);
 private:
@@ -48,7 +49,6 @@ private:
     void addMECARD(QString user_data);
     void openGeo(QString data);
 
-    bool ready;
     QString buttonText;
     QString barcodeText;
     QString barcodeInformativeText;
